@@ -1,7 +1,7 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab:
 // kate: indent-mode csands; indent-width 4; replace-tabs-save off; replace-tabs off; replace-trailing-space-save off; space-indent off; tabs-indents on; tab-width 4;
 /*
-Gwenview - A simple image viewer for KDE
+Gwenview - A simple image viewer for TDE
 Copyright 2005 Aurelien Gateau
 
 This program is free software; you can redistribute it and/or
@@ -32,7 +32,7 @@ namespace Gwenview {
 
 class VTabWidget : public TQWidget {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	VTabWidget(TQWidget* parent);
 	virtual ~VTabWidget();
