@@ -1,6 +1,6 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab
 /*
-Gwenview - A simple image viewer for KDE
+Gwenview - A simple image viewer for TDE
 Copyright 2006 Aurélien Gâteau
 
 This program is free software; you can redistribute it and/or
@@ -32,7 +32,7 @@ class ImageView;
 
 class BCGDialog : public KDialogBase {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	BCGDialog(ImageView*);
 	~BCGDialog();
