@@ -1,6 +1,6 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab
 /*
-Gwenview - A simple image viewer for KDE
+Gwenview - A simple image viewer for TDE
 Copyright 2000-2004 Aurlien Gteau
 
 This program is free software; you can redistribute it and/or
@@ -22,7 +22,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #define IMAGESAVEDIALOG_H
 
 // KDE includes
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 
 class TQString;
 class TQWidget;
@@ -32,7 +32,7 @@ class KURL;
 namespace Gwenview {
 class ImageSaveDialog : public KFileDialog {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	ImageSaveDialog(KURL& url,const TQCString& imageFormat,TQWidget* parent);
 	TQCString imageFormat() const { return mImageFormat; }
